{% extends "registration/base.html" %}

{% load i18n %}

{% block content %}
    <p>
        {% blocktrans trimmed %}
            We’ve emailed you instructions for setting your password,
            if an account exists with the email you entered.
            You should receive them shortly.
        {% endblocktrans %}
    </p>
    <p>
        {% blocktrans trimmed %}
            If you don’t receive an email, please make sure
            you’ve entered the address you registered with,
            and check your spam folder.
        {% endblocktrans %}
    </p>
{% endblock %}
