{% load i18n admin_urls dashub %}

{% block submit-row %}
<div>
    {% if show_save %}
        <div class="form-group">
            <input type="submit" value="{% trans 'Save' %}" class="btn btn btn-success" name="_save">
        </div>
    {% endif %}
    {% if show_delete_link and original %}
        <div class="form-group">
            {% url opts|admin_urlname:'delete' original.pk|admin_urlquote as delete_url %}
            <a href="{% add_preserved_filters delete_url %}" class="btn btn-danger">{% trans "Delete" %}</a>
        </div>
    {% endif %}
    {% if show_save_as_new %}
        <div class="form-group">
            <input type="submit" class="btn btn-info" value="{% trans 'Save as new' %}" name="_saveasnew">
        </div>
    {% endif %}
    {% if show_save_and_add_another %}
        <div class="form-group">
            <input type="submit" class="btn btn-info" value="{% trans 'Save and add another' %}" name="_addanother">
        </div>
    {% endif %}
    {% if show_save_and_continue %}
        <div class="form-group">
            <input type="submit" class="btn btn-info" value="{% if can_change %}{% trans 'Save and continue editing' %}{% else %}{% trans 'Save and view' %}{% endif %}" name="_continue">
        </div>
    {% endif %}
    {% if show_close %}
        <div class="form-group">
            <a href="{% url opts|admin_urlname:'changelist' %}" class="btn btn-info">{% trans 'Close' %}</a>
        </div>
    {% endif %}

    {% block extra-actions %}{% endblock %}

</div>
{% endblock %}

