{% extends "registration/base.html" %}

{% load i18n %}

{% block content %}
    <p class="login-box-msg">{% trans "Your password has been set.  You may go ahead and log in now." %}</p>
    <div class="row">
        <div class="col-12">
            <a href="{{ login_url }}">
                <button class="btn btn-primary btn-block">{% trans 'Log in' %}</button>
            </a>
        </div>
    </div>
{% endblock %}
